==> apache-qpid-jms-1.4.1-src.tar.gz: apache-qpid-jms-1.4.1-src/qpid-jms-client/src/main/java/org/apache/qpid/jms/provider/exceptions/ProviderConnectionRemotelyClosedException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms.provider.exceptions;

import javax.jms.JMSException;

import org.apache.qpid.jms.JmsConnectionRemotelyClosedException;

public class ProviderConnectionRemotelyClosedException extends ProviderIOException {

    private static final long serialVersionUID = 5728349272688210550L;

    public ProviderConnectionRemotelyClosedException(String message) {
        super(message);
    }

    public ProviderConnectionRemotelyClosedException(String message, Throwable cause) {
        super(message, cause);
    }

    @Override
    public JMSException toJMSException() {
        JmsConnectionRemotelyClosedException jmsEx = new JmsConnectionRemotelyClosedException(getMessage());
        jmsEx.initCause(this);
        jmsEx.setLinkedException(this);
        return jmsEx;
    }
}

==> apache-qpid-jms-2.4.0-src.tar.gz: apache-qpid-jms-2.4.0-src/qpid-jms-client/src/main/java/org/apache/qpid/jms/provider/exceptions/ProviderConnectionRemotelyClosedException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms.provider.exceptions;

import jakarta.jms.JMSException;

import org.apache.qpid.jms.JmsConnectionRemotelyClosedException;

public class ProviderConnectionRemotelyClosedException extends ProviderIOException {

    private static final long serialVersionUID = 5728349272688210550L;

    public ProviderConnectionRemotelyClosedException(String message) {
        super(message);
    }

    public ProviderConnectionRemotelyClosedException(String message, Throwable cause) {
        super(message, cause);
    }

    @Override
    public JMSException toJMSException() {
        JmsConnectionRemotelyClosedException jmsEx = new JmsConnectionRemotelyClosedException(getMessage());
        jmsEx.initCause(this);
        jmsEx.setLinkedException(this);
        return jmsEx;
    }
}
